@@ -42,6 +42,11 @@ class DependencyInfo(BaseModel):
 FieldDepMapAlias = T.Dict[str, DependencyInfo]
 
 
+class FilterConnector(str, Enum):
+    AND = " AND "
+    OR = " OR "
+
+
 class Resolver(BaseModel, T.Generic[NodeType]):
     """Can construct an EdgeQL query string from this!"""
 
@@ -216,17 +221,23 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         self: ThisResolverType,
         filter_str: str,
         variables: T.Optional[T.Dict[str, T.Any]] = None,
+        connector: FilterConnector = None,
     ) -> ThisResolverType:
-        if self._filter:
+        if self._filter and not connector:
             raise ResolverException(
                 f"Filter of {self._filter} has already been provided."
             )
         # TODO change variable names
         self._add_variables(variables)
-        self._filter = filter_str
+        if not self._filter:
+            self._filter = ""
+        else:
+            if connector:
+                self._filter += connector.value
+        self._filter += filter_str
         return self
 
-    def filter_by(self, **kwargs):
+    def filter_by(self, connector: FilterConnector = None, **kwargs):
         """For now, only expecting one key value pair to be given, but could be more in future"""
         kwargs = {k: v for k, v in kwargs.items() if v is not None}
         if not kwargs:
@@ -240,9 +251,11 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             filter_strs.append(f".{field_name} = <{cast}>${variable_name}")
             variables[variable_name] = field_value
         filter_str = " AND ".join(filter_strs)
-        return self.filter(filter_str=filter_str, variables=variables)
+        return self.filter(
+            filter_str=filter_str, variables=variables, connector=connector
+        )
 
-    def filter_in(self, **kwargs: list):
+    def filter_in(self, connector: FilterConnector = None, **kwargs: list):
         kwargs = {k: v for k, v in kwargs.items() if v is not None}
         if not kwargs:
             raise ResolverException("Nothing to filter by.")
@@ -257,7 +270,9 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             )
             variables[variable_name] = value_lst
         filter_str = " AND ".join(filter_strs)
-        return self.filter(filter_str=filter_str, variables=variables)
+        return self.filter(
+            filter_str=filter_str, variables=variables, connector=connector
+        )
 
     def extra_fields(
         self: ThisResolverType,
